@@ -3,7 +3,7 @@ using namespace Rcpp;
 
 // Count the number of unique values in each column
 // [[Rcpp::export]]
-IntegerVector C_countUniques(IntegerMatrix x){
+IntegerVector C_countUniques(const IntegerMatrix x){
   int n=x.nrow(), p=x.ncol();
   IntegerVector nVals(p);
   for (int j=0; j<p; j++){
@@ -17,7 +17,7 @@ IntegerVector C_countUniques(IntegerMatrix x){
 
 // Identify duplicated rows in a matrix
 // [[Rcpp::export]]
-LogicalVector C_duplicatedMat(IntegerMatrix x){
+LogicalVector C_duplicatedMat(const IntegerMatrix x){
   int n=x.nrow(), p=x.ncol();
   IntegerVector nv=C_countUniques(x);
   IntegerVector f(nv.size());
@@ -41,7 +41,7 @@ LogicalVector C_duplicatedMat(IntegerMatrix x){
   
 // Eliminate duplicated rows in a matrix
 // [[Rcpp::export]]
-IntegerMatrix C_uniqueMat(IntegerMatrix x){
+IntegerMatrix C_uniqueMat(const IntegerMatrix x){
   LogicalVector keep=!C_duplicatedMat(x);
   int n=x.nrow(), p=x.ncol(), m=sum(as<IntegerVector>(keep));
   IntegerMatrix out(m, p);
@@ -59,7 +59,7 @@ IntegerMatrix C_uniqueMat(IntegerMatrix x){
     
 // Subsetting an IntegerMatrix by column
 // [[Rcpp::export]]
-IntegerMatrix C_selectCols(IntegerMatrix x, IntegerVector idx){
+IntegerMatrix C_selectCols(const IntegerMatrix x, const IntegerVector idx){
   int n=x.nrow(), r=idx.size();
   IntegerMatrix out(n, r);
   for (int i=0; i<n; i++){
@@ -72,7 +72,7 @@ IntegerMatrix C_selectCols(IntegerMatrix x, IntegerVector idx){
 
 // Unique rows from a subset of the columns of a matrix
 // [[Rcpp::export]]
-IntegerMatrix C_uniqueCombs(IntegerMatrix x, IntegerVector idx){
+IntegerMatrix C_uniqueCombs(const IntegerMatrix x, const IntegerVector idx){
   return C_uniqueMat(C_selectCols(x, idx));
 }
 
